@@ -374,6 +374,7 @@ async fn resume() {
 
 #[tokio::test]
 async fn custom_mirror() {
+    let mut repo = EbuildRepoBuilder::new().build().unwrap();
     let server = MockServer::start().await;
     let uri = server.uri();
     let name = "mocked";
@@ -384,10 +385,10 @@ async fn custom_mirror() {
         .mount(&server)
         .await;
 
-    let mut repo = EbuildRepoBuilder::new().build().unwrap();
+    // file without subdirectory
     let data = indoc::formatdoc! {r#"
         EAPI=8
-        DESCRIPTION="ebuild with custom mirror"
+        DESCRIPTION="ebuild using custom mirror"
         SRC_URI="mirror://{name}/file1"
         SLOT=0
     "#};
@@ -422,6 +423,39 @@ async fn custom_mirror() {
         .success();
     let data = fs::read_to_string("file1").unwrap();
     assert_eq!(&data, "test1");
+
+    // file with subdirectory
+    let data = indoc::formatdoc! {r#"
+        EAPI=8
+        DESCRIPTION="ebuild using custom mirror with subdirectory"
+        SRC_URI="mirror://{name}/path/to/file2"
+        SLOT=0
+    "#};
+    repo.create_ebuild_from_str("cat/pkg-1", &data).unwrap();
+
+    // mirror with subdirectory
+    fs::write(
+        repo.path().join("profiles/thirdpartymirrors"),
+        format!("{name} {uri}/invalid1 {uri}/invalid2 {uri}/mirror-dir/"),
+    )
+    .unwrap();
+
+    // mirrored file combining SRC_URI subdirectory with mirror subdirectory
+    Mock::given(method("GET"))
+        .and(path("/mirror-dir/path/to/file2"))
+        .respond_with(ResponseTemplate::new(200).set_body_bytes(b"test2"))
+        .mount(&server)
+        .await;
+
+    // iterate through mirrors until download succeeds
+    cmd("pk pkg fetch")
+        .arg(&repo)
+        .assert()
+        .stdout("")
+        .stderr("")
+        .success();
+    let data = fs::read_to_string("file2").unwrap();
+    assert_eq!(&data, "test2");
 }
 
 #[tokio::test]
